@@ -2,7 +2,9 @@
 # frozen_string_literal: true
 
 module TZInfo
-  using UntaintExt if TZInfo.const_defined?(:UntaintExt)
+  # Use send as a workaround for erroneous 'wrong number of arguments' errors
+  # with JRuby 9.0.5.0 when calling methods with Java implementations. See #114.
+  send(:using, UntaintExt) if TZInfo.const_defined?(:UntaintExt)
 
   module DataSources
     # An {InvalidZoneinfoDirectory} exception is raised if {ZoneinfoDataSource}
